@@ -14,7 +14,6 @@ from uuid import UUID
 import networkx as nx
 
 from openeo_pg_parser_networkx.pg_schema import (
-    ParameterReference,
     PGEdgeType,
     ProcessGraph,
     ProcessNode,
@@ -230,7 +229,6 @@ class OpenEOProcessGraph:
         )
 
         for arg_name, unpacked_arg in self._EVAL_ENV.node.arguments.items():
-
             # Put the raw arg into the resolved_kwargs dict. If there are no further references within, that's already the right kwarg to pass on.
             # If there are further references, doing this will ensure that the container for these references is already there
             # and the access_functions can inject the resolved parameters later.
@@ -421,6 +419,13 @@ class OpenEOProcessGraph:
         ][0]
 
     def plot(self, reverse=False):
+        try:
+            import matplotlib.pyplot as plt
+        except ImportError:
+            raise ImportError(
+                "Not possible to plot process graph, because the `plot` extra is not installed. You can enable this by installing this package with the `plot` extra:  `pip install openeo-pg-parser-networkx[plot]`."
+            )
+
         if reverse:
             self.G = self.G.reverse()
 
@@ -452,9 +457,6 @@ class OpenEOProcessGraph:
             for edge in self.G.edges
         ]
 
-        # To help with truncated labels
-        import matplotlib.pyplot as plt
-
         plt.margins(x=0.2)
 
         nx.draw_circular(
